# Gyna

**Pre-alpha warning: this project is under development. **

## License

Gyna is released under the term of the [BSD 3-Clause license](LICENSE.txt)
Copyright (c) 2025, Nicolas Desprès
All rights reserved.
